@@ -1,6 +1,6 @@
 import os
 import argparse
-from .agent import run_agent
+from agent import run_agent
 from time import sleep
 
 
