@@ -3,7 +3,8 @@
 import logging.handlers
 import signal
 import sys
-from os.path import join
+# from os.path import join
+from taskmanager import TaskManager
 
 
 def run_agent(debug=False, verbose=True):
@@ -26,11 +27,13 @@ def run_agent(debug=False, verbose=True):
     stdout_handler = logging.StreamHandler(sys.stdout)
     log.addHandler(stdout_handler)
 
+    r = TaskManager(True, 20, "instance_details")
+
     def sigint_handler(signum, frame):
         # Log
         log.debug("Signal Received: %d" % signum)
         # Stop Agent
-        # r.stop()
+        r.stop()
 
         # Set the signal handler
         signal.signal(signal.SIGINT, sigint_handler)  # Run Agent
@@ -39,7 +42,7 @@ def run_agent(debug=False, verbose=True):
     signal.signal(signal.SIGINT, sigint_handler)
     signal.signal(signal.SIGTERM, sigint_handler)
 
-    # r.start()
+    r.start()
 
 
 if __name__ == '__main__':
